#include "draglistview.h"
#include "kmpModule.h"
#include "dragListViewItem.h"
#include<qheader.h>
#include <qdragobject.h>

dragListView::dragListView(QWidget *parent, const char *name )
               : QListView( parent, name )
{
    setAcceptDrops(TRUE);
    dropPainted = 0;
}

dragListView::~dragListView() {
}

void dragListView::setType(int type) {
    type_ = type;
}

void dragListView::startDrag()
{
    if(type_ == 1) {
        QDragObject *d = new QStoredDrag(QString("kmp_dir"),  this);
        d->dragCopy();
    } else if(type_ == 2) {
        QDragObject *d = new QStoredDrag(QString("kmp_file"), this);
        d->dragCopy();
    } else {
        QDragObject *d = new QStoredDrag(QString("kmp_pl"), this);
        d->dragCopy();
    }
    
}
void dragListView::dragEnterEvent(QDragEnterEvent* event)
{
    
    if(type_ == 0) { event->accept(event->provides(QString("kmp_dir")) || event->provides(QString("kmp_file")) || event->provides(QString("kmp_pl")));
    } else event->accept(0);
    
}
void dragListView::dropEvent(QDropEvent* event)
{
    if(dropPainted) {
 dropPainted->setPaintDrop(0);
 dropPainted->repaint();
 dropPainted = 0;
    }
    if ( event->provides(QString("kmp_dir"))) {
        event->accept(1);
        recieveDrop(QString("kmp_dir"), (dragListView *)event->source(), findItem(event->pos()));
    }else if(event->provides(QString("kmp_file"))) {
        event->accept(1);
        recieveDrop(QString("kmp_file"), (dragListView *)event->source(), findItem(event->pos()));
    }else if(event->provides(QString("kmp_pl"))) {
        recieveDrop(QString("kmp_pl"), (dragListView *)event->source(), findItem(event->pos()));
    }
  
}
void dragListView::setPath(QString path) {
    path_ = path;
}

QString dragListView::getPath() {
    return path_;
}

void dragListView::resizeEvent(QResizeEvent * e) {
    resized(e);    
    QListView::resizeEvent(e);
    this->triggerUpdate();
}
void dragListView::dragMoveEvent ( QDragMoveEvent * e)
{    
    dragListViewItem * theItem = findItem(e->pos());
    if(theItem) {
        if(theItem == dropPainted) return;
        if(dropPainted) {
            dropPainted->setPaintDrop(0);
            dropPainted->repaint();
        }
       
        theItem->setPaintDrop(1);
        theItem->repaint();
        dropPainted = theItem;
    } else {
        if(dropPainted) {
            dropPainted->setPaintDrop(0);
            dropPainted->repaint();
            dropPainted = 0;
        }
    }
}
void dragListView::dragLeaveEvent ( QDragLeaveEvent * e)
{
    
    QDragLeaveEvent toPreventWarning = *e;
    if(dropPainted) {
        dropPainted->setPaintDrop(0);
        dropPainted->repaint();
        dropPainted = 0;
    }
    
}

dragListViewItem * dragListView::findItem(QPoint loc)
{
    int verOffset = header()->sectionRect(0).height();
    return ((dragListViewItem *) itemAt (QPoint(loc.x(), loc.y() - verOffset)));   
}

    





